@@ -5,6 +5,9 @@
 # @File     : plugin.py
 # @Project  : PyCharm
 
+class Plugin:
+    pass
+
 
 def plugins():
     return ["pytest_mini.fixture"]
